<?xml version='1.0' encoding='UTF-8'?>
<!-- eSlomsek                                                       -->
<!-- Digital text-critical editions of Slovene literature           -->
<!-- ZRC SAZU, IJS                                                  -->
<!--                                                                -->
<!-- Full stylesheet for conversion of TEI eSlomsek to HTML         -->
<!--                                                                -->
<!-- Toma&zcaron; Erjavec,                                          -->
<!-- 2007-04-10                                                     -->

<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:exsl="http://exslt.org/common"
    exclude-result-prefixes="exsl" 
    extension-element-prefixes="exsl"
    version="1.1">
 
    <xsl:import href="hdr2html.xsl"/>
    
    <xsl:param name="outName">slomsek</xsl:param>
    <xsl:param name="outDir"></xsl:param>
    <xsl:param name="split"/>
    <xsl:param name="debug"/>
    <xsl:param name="verbose">yes</xsl:param>
    
    <xsl:param name="outFile" select="concat($outName,'.html')"/>
    
    <xsl:param name="homeURL" select="$outFile"/>
    <xsl:param name="teiHeader-en" select="concat($outName,'.teiHeader','-en','.html')"/>
    <xsl:param name="teiHeader-sl" select="concat($outName,'.teiHeader','-sl','.html')"/>
    <xsl:param name="teiHeader-desc-en">ENGLISH TEI HEADER</xsl:param>
    <xsl:param name="teiHeader-desc-sl">Kolofon TEI</xsl:param>
    
    <xsl:variable name="css_style">
      BODY      { 
      color: #000000;
      background-color: #FFFFCC;
      font-family: "Times New Roman", "Times";
      }
      A:visited { color: #000077;}
      .normal   { font-family: Times; }
      .break    { margin-top: 3px; margin-bottom: 3px}
      .center   { text-align: center; }
      .right    { text-align: right; }
      .justify  { text-align: justify; }
      .suphead  { font-weight: normal; }
      .subhead  { font-weight: normal; font-size: small}
    </xsl:variable>
    
    <xsl:param name="def-title">
      <xsl:text>e-Slomšek</xsl:text>
    </xsl:param>
    
    <xsl:variable name="html-footer1">
      <hr/>
      <SMALL>
        Avtorske pravice za to izdajo ureja licenca <!-- Uredni bljah: To delo je licencirano <sic>z</sic> --> 
        <a rel="license" href="http://creativecommons.org/licenses/by-sa/2.5/si/">Creative Commons Priznanje avtorstva-Deljenje pod enakimi pogoji 2.5 Slovenija</a>
        <br/>Projekt 
        <A HREF="http://nl.ijs.si/e-zrc/">Elektronske 
          znanstvenokriti&#x10D;ne izdaje slovenskega slovstva</A> 
        <BR/>
        Datoteka HTML narejena s pretvorbo XSLT baze 
        XML/<A HREF="http://www.tei-c.org/P4X/">TEI P4</A>.
      </SMALL>
    </xsl:variable>
    <xsl:variable name="html-footer2">
      <SMALL>
        <BR/>
        <A HREF="http://validator.w3.org/check?uri=referer"><IMG border="0"
          src="http://www.w3.org/Icons/valid-html401"
          alt="Valid HTML 4.01!" height="31" width="88"/></A>
        <A HREF="http://jigsaw.w3.org/css-validator/"><IMG border="0"
          src="http://www.w3.org/Icons/valid-css" 
          alt="Valid CSS!" height="31" width="88" /></A> 
        <xsl:comment>Creative Commons License</xsl:comment>
        <a rel="license" href="http://creativecommons.org/licenses/by-sa/2.5/si/"><img alt="Creative Commons License" style="border-width: 0" src="http://i.creativecommons.org/l/by-sa/2.5/si/88x31.png"/></a>
        <xsl:comment>/Creative Commons License</xsl:comment>
        <xsl:comment>
          <rdf:RDF xmlns="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#">
            <Work rdf:about="">
              <license rdf:resource="http://creativecommons.org/licenses/by-sa/2.5/si/" />
            </Work>
            <License rdf:about="http://creativecommons.org/licenses/by-sa/2.5/si/"><permits rdf:resource="http://web.resource.org/cc/Reproduction"/><permits rdf:resource="http://web.resource.org/cc/Distribution"/><requires rdf:resource="http://web.resource.org/cc/Notice"/><requires rdf:resource="http://web.resource.org/cc/Attribution"/><permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/><requires rdf:resource="http://web.resource.org/cc/ShareAlike"/></License></rdf:RDF> 
        </xsl:comment>
      </SMALL>
    </xsl:variable>
    
<xsl:output
  method="html"
  encoding="utf-8"
  indent = "no"/> 

<xsl:strip-space elements="div page"/>
<xsl:preserve-space elements="line note"/>

  <xsl:template match="/">
    <xsl:call-template name="outputChunk">
      <xsl:with-param name="outFile" select="$teiHeader-sl"/>
      <xsl:with-param name="title" 
        select="concat($teiHeader-desc-sl,': ',
        //teiHeader/fileDesc/titleStmt/title[not(@lang) or @lang='sl'])"/>
      <xsl:with-param name="content">
        <xsl:apply-templates select="TEI.2/teiHeader"/>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates select="TEI.2/text"/>
  </xsl:template>
  
  <xsl:template match="text">
    <xsl:variable name="title">
      <xsl:choose>
        <xsl:when test="//teiHeader">
          <xsl:value-of select="//fileDesc/titleStmt/title"/>
          <xsl:text> (</xsl:text>
          <xsl:value-of select="//teiHeader/@date.updated"/>
          <xsl:text>)</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select="$def-title"/>
          <xsl:text></xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="head">
      <xsl:choose>
        <xsl:when test="//teiHeader">
          <H1 align="center">
            <xsl:value-of select="$title"/>
          </H1>
          <xsl:for-each select="//fileDesc/titleStmt/author">
            <H2><xsl:value-of select="."/></H2>
          </xsl:for-each>
          <H2>Izdaja <xsl:value-of select="//editionStmt/edition"/></H2>
          <xsl:for-each select="//fileDesc/titleStmt/respStmt">
            <H3>
              <xsl:value-of select="resp"/>
              <xsl:text> </xsl:text>        
              <xsl:value-of select="name"/>
            </H3>
          </xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
          <H1 align="center">
            <xsl:copy-of select="$def-title"/>
          </H1>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:call-template name="outputChunk">
      <xsl:with-param name="outFile" select="$outFile"/>
      <xsl:with-param name="title" select="$def-title"/>
      <xsl:with-param name="content">
        <xsl:apply-templates select="front/titlePage"/>
        <xsl:call-template name="toc"/>
        <xsl:apply-templates select="front/div"/>
        <xsl:apply-templates select="body"/>
        <xsl:apply-templates select="back"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>


  <xsl:template name="outputChunk">
    <xsl:param name="outFile" select="concat(@id,'.html')"/>
    <xsl:param name="absFile" select="concat($outDir,$outFile)"/>
    <xsl:param name="title">
      <xsl:value-of select="@id"/>
    </xsl:param>
    <xsl:param name="content"/>
    <xsl:choose>
      <xsl:when test="element-available('exsl:document')">
        <xsl:if test="$verbose='yes'">
          <xsl:message>Opening <xsl:value-of select="$absFile"/></xsl:message>
        </xsl:if>
        <exsl:document         
          encoding="utf-8" 
          method="html" 
          doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" 
          href="{$absFile}">
          <HTML>
            <xsl:comment>THIS FILE IS GENERATED FROM AN XML MASTER. DO NOT EDIT!</xsl:comment>
            <xsl:text>&#10;</xsl:text>
            <HEAD>
              <TITLE>
                <xsl:value-of select="normalize-space($title)"/>
              </TITLE>
              <META http-equiv="Content-Type" content="text/html; charset=utf-8"/>
              <STYLE TYPE="text/css">
                <xsl:value-of select="$css_style"/>
              </STYLE>
            </HEAD>
            <BODY>
              <xsl:copy-of select="$content"/>
              <xsl:copy-of select="$html-footer1"/>
              <xsl:if test="not(ancestor-or-self::teiHeader or descendant::teiHeader)">
                <xsl:copy-of select="$html-footer2"/>
              </xsl:if>
            </BODY>
          </HTML>
        </exsl:document> 
        <xsl:if test="$verbose='yes'">
          <xsl:message>Closing <xsl:value-of select="$absFile"/></xsl:message>
        </xsl:if>
      </xsl:when>
      <xsl:otherwise>
        <xsl:if test="$verbose='yes'">
          <xsl:message>Creation of 
            <xsl:value-of select="$absFile"/> not possible</xsl:message>
        </xsl:if>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="body">
    <HR/>
    <xsl:if test="$split">
      <H2 align="center">PRIDIGE</H2>
      <UL>
        <xsl:apply-templates mode="toc" select="div"/>
      </UL>
    </xsl:if>
    <xsl:apply-templates/>
  </xsl:template>
  
  <xsl:template match="front">
    <xsl:apply-templates/>
    <HR/>
  </xsl:template>
  
  <xsl:template match="docImprint">
    <H4 align="center">
      <xsl:apply-templates/>
    </H4>
  </xsl:template>
  
  <xsl:template match="docAuthor">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>
  
  <xsl:template match="byline/docAuthor">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="byline">
    <H3 align="center">
      <xsl:apply-templates/>
    </H3>
  </xsl:template>
  
<xsl:template match="back">
  <HR/>
  <xsl:apply-templates/>
</xsl:template>

<!--xsl:template match="body/div">
  <xsl:choose>
    <xsl:when test="$split">
      <xsl:call-template name="outputChunk">
        <xsl:with-param name="content">
          <html>
            <xsl:comment>THIS FILE IS GENERATED FROM AN XML MASTER. 
            DO NOT EDIT</xsl:comment>
            <head>
              <title>
                <xsl:value-of select="//fileDesc/titleStmt/title"/>
                (<xsl:value-of select="//teiHeader/@date.updated"/>)
                <xsl:value-of select="head"/>
              </title>
              <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
            </head>
            <body background="img/background.jpg">
              <h1>
                <xsl:value-of select="//fileDesc/titleStmt/title"/>
              </h1>
              <xsl:for-each select="//fileDesc/titleStmt/author">
                <h2><xsl:value-of select="."/></h2>
              </xsl:for-each>
              <H2>
                <xsl:apply-templates mode="toc" select="head"/>
              </H2>
              <H3>
                <xsl:text>Kazalo</xsl:text>
              </H3>
              <UL>
                <xsl:apply-templates mode="toc" select="div | divGen"/>
                <LI>
                  <A href="{$outName}.html">
                    <xsl:text>na glavno kazalo</xsl:text>        
                  </A>
                </LI>
              </UL>
              <xsl:apply-templates select="div | divGen"/>
            </body>
          </html>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <HR/>
      <xsl:call-template name="anchor"/>  
      <xsl:apply-templates/>
    </xsl:otherwise>
  </xsl:choose-->

  <xsl:template match="div[@type='sermon']">
    <xsl:if test="$verbose='yes'">
      <xsl:message>Processing div <xsl:value-of select="@id"/></xsl:message>
    </xsl:if>
    <xsl:choose>
      <xsl:when test="$split">
        <xsl:call-template name="outputChunk">
          <xsl:with-param name="outFile" select="concat($outName,'-',@id,'.html')"/>
          <xsl:with-param name="title">
            <xsl:value-of select="$def-title"/>
            <xsl:text>: </xsl:text>
            <xsl:apply-templates mode="toc" select="head"/>
          </xsl:with-param>
          <xsl:with-param name="content">
            <xsl:call-template name="sermon"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <HR/>
        <xsl:apply-templates select="head"/>
        <xsl:call-template name="sermon"/>
        <HR/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="sermon">
    <xsl:call-template name="anchor"/>
    <h1>
      <xsl:value-of select="//fileDesc/titleStmt/title"/>
    </h1>
    <H2>
      <xsl:apply-templates mode="toc" select="head"/>
    </H2>
    <H3>Kazalo</H3>
    <UL>
      <xsl:if test="not($debug)">
        <xsl:apply-templates select="div | divGen" mode="toc"/>
      </xsl:if>
      <LI>
        <A href="{$outName}.html#TOC">
          <xsl:text>na glavno kazalo</xsl:text>
        </A>
      </LI>
    </UL>
    <HR/>
         <xsl:apply-templates select="div | divGen"/>
  </xsl:template>
  
<xsl:template match="div[@type='facs']"/>

<xsl:template match="div[@type='notes']">
  <HR/>
  <xsl:call-template name="anchor"/>  
  <xsl:apply-templates select="head"/>
  <OL>
    <xsl:attribute name="start">
      <xsl:value-of select="note[1]/@n"/>
    </xsl:attribute>
    <xsl:apply-templates select="note"/>
  </OL>
</xsl:template>

<xsl:template match="div">
  <xsl:call-template name="anchor"/>  
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="divGen">
  <xsl:call-template name="anchor"/>  
  <h2>
    <xsl:apply-templates select="../head"/>
  </h2>
  <h2 align="center">Vzporedni prikaz</h2>
  <xsl:apply-templates select="id(@corresp)[@type='dipl']" mode="para"/>
</xsl:template>

<xsl:template match="ref">
  <xsl:variable name="base">
    <xsl:if test="$split">
      <xsl:value-of select="concat($outName,'.html')"/>
    </xsl:if>
  </xsl:variable>
  <A href="{$base}#{@target}">
    <xsl:apply-templates/>
  </A>
</xsl:template>

  
  <xsl:template match="xref">
    <A href="{@url}">
      <xsl:apply-templates/>
    </A>
  </xsl:template>
  
<xsl:template match="note[@type='bibl']/xref">
  <a href="{@url}">
  <!--a>
    <xsl:attribute name="href">
      <xsl:text>http://www.biblija.net/biblija.cgi?lang=sl&amp;m=</xsl:text>
      <xsl:value-of select="@url"/>
    </xsl:attribute-->
    <xsl:apply-templates/>
  </a>
</xsl:template>

<xsl:template match="p">
  <xsl:copy>
    <xsl:apply-templates/>
  </xsl:copy>
</xsl:template>

<xsl:template match="page">
  <table>
    <tr>
      <td valign="top">
        <xsl:call-template name="figure"/>  
      </td>
      <td>
        <table>
          <xsl:apply-templates/>
        </table>
      </td>
    </tr>
  </table>
 <HR/>
</xsl:template>

<xsl:template match="page" mode="para">
  <table>
    <tr>
      <td valign="top">
        <xsl:call-template name="figure"/>  
      </td>
      <td>
        <table>
          <xsl:apply-templates mode="para"/>
        </table>
      </td>
    </tr>
  </table>
 <HR/>
</xsl:template>

<xsl:template match="line">
  <tr>
    <xsl:call-template name="line"/>  
  </tr>
</xsl:template>

<xsl:template match="line" mode="para">
  <tr>
    <xsl:call-template name="line"/>  
  </tr>
  <xsl:apply-templates select="id(@corresp)" mode="para2"/>
  <tr><td></td></tr>
</xsl:template>

<xsl:template match="line" mode="para2">
  <tr style="color: fuchsia">
    <xsl:call-template name="line"/>  
  </tr>
</xsl:template>

<xsl:template match="sic">
  <font color='red'><xsl:apply-templates/></font>
</xsl:template>


<xsl:template match="line/note"/>

<xsl:template match="note[@place='end']">
  <!--
  <H4>
    <xsl:value-of select="@n"/>
    <xsl:number/>
  </H4>
  -->
  <LI>
    <xsl:call-template name="anchor"/>  
    <xsl:text>[</xsl:text>
    <A>
      <xsl:attribute name="href">
        <xsl:text>#</xsl:text>
        <xsl:value-of select="@target"/>
      </xsl:attribute>
      <xsl:value-of select="@target"/>
    </A>
    <xsl:if test="@targetEnd">
      <xsl:text>-</xsl:text>
      <A>
        <xsl:attribute name="href">
          <xsl:text>#</xsl:text>
          <xsl:value-of select="@targetEnd"/>
        </xsl:attribute>
        <xsl:value-of select="@targetEnd"/>
      </A>
    </xsl:if>
    <xsl:text>]</xsl:text>
    <xsl:apply-templates/>
  </LI>
</xsl:template>

<xsl:template match="note" mode="show">
  <EM><xsl:apply-templates/></EM>
</xsl:template>
<xsl:template match="note[@place='foot' or @place='inline']">
  <EM><xsl:apply-templates/></EM>
</xsl:template>

  <xsl:template match="titlePage">
    <xsl:apply-templates/>
    <HR/>
  </xsl:template>
  
  <xsl:template match="docTitle">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>
  
  <xsl:template match="docTitle[titlePart]">
    <xsl:apply-templates/>
  </xsl:template>
  
  <xsl:template match="titlePart">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>
  
  <xsl:template match="titlePart[@type='subtitle']">
    <H2 align="center">
      <xsl:apply-templates/>
    </H2>
  </xsl:template>
  
  <xsl:template match="docImprint">
    <H4 align="center">
      <xsl:apply-templates/>
    </H4>
  </xsl:template>
  
  <xsl:template match="docAuthor">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>
  
  <xsl:template match="byline/docAuthor">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="byline">
    <H3 align="center">
      <xsl:apply-templates/>
    </H3>
  </xsl:template>
  
  <xsl:template match="lb">
    <BR/>
  </xsl:template>
  
<xsl:template match="hi[@rend='sup']"><sup><xsl:apply-templates/></sup></xsl:template>
<xsl:template match="hi"><i><xsl:apply-templates/></i></xsl:template>

<xsl:template match="emph"><u><xsl:apply-templates/></u></xsl:template>

<xsl:template match="add[@hand='AMS']"><sup><xsl:apply-templates/></sup></xsl:template>
<xsl:template match="add[@hand='JFA']">[<xsl:apply-templates/>]</xsl:template>
<xsl:template match="add[@hand='MOG']">[<xsl:apply-templates/>]</xsl:template>

<xsl:template match="del[@hand='AMS']"><s><xsl:apply-templates/></s></xsl:template>
<xsl:template match="del[@hand='JFA']">&#x2026;</xsl:template>
<xsl:template match="del[@hand='MOG']">
  <s><xsl:apply-templates/></s>
</xsl:template>

<xsl:template match="gap[ancestor::div[@type='crit']]">&#x2026;</xsl:template>
<xsl:template match="gap[ancestor::div[@type='dipl']]"> <i>(besedilo uni&#x010D;eno)</i></xsl:template>
<xsl:template match="gap"> <b>(besedilo uni&#x010D;eno)</b> </xsl:template>
<xsl:template match="supplied"> !!!<xsl:apply-templates/>!!! </xsl:template>

<!-- Named templates -->

  <xsl:template name="toc">
    <A name="TOC"/>
    <H2>Kazalo</H2>
    <xsl:if test="//teiHeader">
      <A HREF="{$teiHeader-sl}">
        <xsl:value-of select="$teiHeader-desc-sl"/>
      </A>
      <P/>
    </xsl:if>
    <xsl:if test="//front">
      <B>UVOD</B>
      <UL>
        <xsl:apply-templates mode="toc" select="/TEI.2/text/front/div"/>
      </UL>
    </xsl:if>
    <B>PRIDIGE</B>
    <UL>
      <xsl:apply-templates mode="toc" select="/TEI.2/text/body/div"/>
    </UL>
    <B>DODATKI</B>
    <xsl:if test="//back">
      <UL>
        <xsl:apply-templates mode="toc" select="/TEI.2/text/back"/>
      </UL>
    </xsl:if>
  </xsl:template>
  
<xsl:template match="div[@type='facs']" mode="toc"/>

<xsl:template match="div | divGen" mode="toc">
  <xsl:variable name="id">
    <xsl:if test="$split and (ancestor::body)">
      <xsl:call-template name="FName">
        <xsl:with-param name="id" select="ancestor-or-self::div[@type='sermon']/@id"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:text>#</xsl:text>
    <xsl:choose>
      <xsl:when test="@id">
        <xsl:value-of select="@id"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="generate-id(.)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <LI>
    <A href="{$id}">
      <xsl:choose>
        <xsl:when test="name() = 'div'">
          <xsl:apply-templates select="head" mode="toc"/>
        </xsl:when>
        <xsl:when test="name() = 'divGen'">
          <xsl:text> Vzporedni prikaz</xsl:text>        
        </xsl:when>
      </xsl:choose>
    </A>
    <xsl:if test="div">
      <OL>
        <xsl:apply-templates select="div|divGen" mode="toc"/>
      </OL>
    </xsl:if>
  </LI>
</xsl:template>

<xsl:template match="head" mode="para"/>

<xsl:template match="head" mode="toc">
  <xsl:apply-templates/>
  <xsl:text> </xsl:text>        
</xsl:template>

<xsl:template match="head">
  <xsl:apply-templates select="../../head"/>
  <h2 align="center">
    <xsl:apply-templates/>
  </h2>
</xsl:template>

<xsl:template match="list">
  <UL>
    <xsl:apply-templates/>
  </UL>
</xsl:template>

<xsl:template match="item">
  <LI>
    <xsl:apply-templates/>
  </LI>
</xsl:template>

<xsl:template match="listBibl">
  <OL>
    <xsl:apply-templates/>
  </OL>
</xsl:template>

<xsl:template match="listBibl/bibl">
  <LI>
    <xsl:call-template name="anchor"/>  
    <xsl:apply-templates/>
  </LI>
</xsl:template>

<xsl:template name="anchor">
  <a>
    <xsl:choose>
      <xsl:when test="@id">
        <xsl:attribute name="name">
          <xsl:value-of select="@id"/>
        </xsl:attribute>
      </xsl:when>
      <xsl:otherwise>
        <xsl:attribute name="name">
          <xsl:value-of select="generate-id(.)"/>
        </xsl:attribute>
      </xsl:otherwise>
    </xsl:choose>
  </a>
</xsl:template>

<xsl:template name="line">
  <td align="right" nowrap="Y">
    <xsl:if test="note[@place='left']">
      <xsl:apply-templates select="note[@place='left']" mode="show"/>  
    </xsl:if>
  </td>
  
  <td>
    <xsl:attribute name="align">
      <xsl:choose>
        <xsl:when test="@rend='center'">center</xsl:when>
        <xsl:when test="@rend='right'">right</xsl:when>
        <xsl:otherwise>left</xsl:otherwise>
      </xsl:choose>
    </xsl:attribute>
    <xsl:apply-templates/>  
  </td>
  
  <td align="left" nowrap="Y">
    <xsl:choose>
      <xsl:when test="note[@place='right']">
        <xsl:apply-templates select="note[@place='right']" mode="show"/>  
      </xsl:when>
    </xsl:choose>
  </td>
  
  <td align="left" nowrap="Y">
    <xsl:variable name="id">
      <xsl:value-of select="@id"/>
    </xsl:variable>
    <xsl:variable name="note">
      <xsl:value-of select="//note[@target = $id or @targetEnd = $id]/@id"/>
    </xsl:variable>
    <small>
      <xsl:choose>
        <xsl:when test="id($note)">
          <xsl:call-template name="anchor"/>  
          <font color='green'>
            <xsl:value-of select="ancestor::div/@n"/>
            <xsl:text>.</xsl:text>
            <xsl:value-of select="@n"/>
          </font>
          <A href="#{$note}">
            <I>
              <xsl:text> op. </xsl:text>
              <xsl:choose>
                <xsl:when test="id($note)[@target = $id]">
                  <xsl:text>[</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>-</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
              <xsl:value-of select="id($note)/@n"/>
              <xsl:choose>
                <xsl:when test="id($note)[@target = $id and @targetEnd]">
                  <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>]</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </I>
          </A>
        </xsl:when>
        <xsl:otherwise>
          <xsl:if test="(@n mod 5) = 0">
            <font color='green'>
              <xsl:value-of select="ancestor::div/@n"/>
              <xsl:text>.</xsl:text>
              <xsl:value-of select="@n"/>
            </font>
          </xsl:if>
        </xsl:otherwise>
      </xsl:choose>
    </small>
  </td>
</xsl:template>

<xsl:template match="line/text()">
  <xsl:value-of select="translate(., '&#x301F;', '=')"/>
</xsl:template>

<xsl:template name="figure">
  <a href="{id(@corresp)/figure[@type='jpeg']/@url}">
    <img src="{id(@corresp)/figure[@type='thmb']/@url}"
      alt="{id(@corresp)/note}"
      />
  </a>
</xsl:template>

<xsl:template name="FName">
  <xsl:param name="id" select="@id"/>
  <xsl:value-of select="$outName"/>
  <xsl:text>-</xsl:text>
  <xsl:value-of select="$id"/>
  <xsl:text>.html</xsl:text>
</xsl:template>

</xsl:stylesheet>
